Coverage report

# Coverage report: 74%

Hot-keys on this page

n s m x b p c change column sorting

Module | statements | missing | excluded | branches | partial | coverage
--- | --- | --- | --- | --- | --- | ---
Total | 2553 | 577 | 2 | 800 | 88 | 74%
jutil/__init__.py | 1 | 0 | 0 | 0 | 0 | 100%
jutil/admin.py | 83 | 3 | 0 | 30 | 3 | 95%
jutil/apps.py | 3 | 0 | 0 | 0 | 0 | 100%
jutil/auth.py | 19 | 1 | 0 | 4 | 1 | 91%
jutil/bank_const_be.py | 2 | 0 | 0 | 0 | 0 | 100%
jutil/bank_const_dk.py | 1 | 0 | 0 | 0 | 0 | 100%
jutil/bank_const_fi.py | 2 | 0 | 0 | 0 | 0 | 100%
jutil/bank_const_iban.py | 1 | 0 | 0 | 0 | 0 | 100%
jutil/bank_const_se.py | 1 | 0 | 0 | 0 | 0 | 100%
jutil/cache.py | 34 | 34 | 0 | 20 | 0 | 0%
jutil/command.py | 89 | 17 | 0 | 48 | 6 | 79%
jutil/dates.py | 148 | 31 | 0 | 52 | 13 | 73%
jutil/dict.py | 8 | 8 | 0 | 0 | 0 | 0%
jutil/email.py | 111 | 82 | 0 | 44 | 5 | 25%
jutil/format.py | 268 | 42 | 0 | 120 | 19 | 82%
jutil/management/__init__.py | 0 | 0 | 0 | 0 | 0 | 100%
jutil/management/commands/__init__.py | 0 | 0 | 0 | 0 | 0 | 100%
jutil/management/commands/make_bank_const_dk.py | 51 | 51 | 0 | 18 | 0 | 0%
jutil/management/commands/make_bank_const_fi.py | 60 | 60 | 0 | 24 | 0 | 0%
jutil/management/commands/make_bank_const_se.py | 84 | 84 | 0 | 40 | 0 | 0%
jutil/management/commands/setpass.py | 19 | 19 | 0 | 4 | 0 | 0%
jutil/management/commands/test_email.py | 36 | 26 | 0 | 10 | 0 | 22%
jutil/middleware.py | 74 | 3 | 0 | 20 | 6 | 90%
jutil/model.py | 62 | 5 | 0 | 28 | 8 | 86%
jutil/modelfields.py | 8 | 0 | 0 | 0 | 0 | 100%
jutil/parse.py | 51 | 6 | 0 | 20 | 2 | 83%
jutil/permissions.py | 12 | 12 | 0 | 2 | 0 | 0%
jutil/request.py | 39 | 16 | 0 | 10 | 2 | 51%
jutil/responses.py | 39 | 20 | 0 | 6 | 0 | 42%
jutil/sms.py | 15 | 15 | 0 | 8 | 0 | 0%
jutil/testing.py | 29 | 5 | 0 | 8 | 4 | 76%
jutil/tests.py | 732 | 19 | 0 | 84 | 3 | 97%
jutil/urls.py | 13 | 1 | 0 | 4 | 1 | 88%
jutil/validators.py | 348 | 8 | 0 | 136 | 9 | 96%
jutil/xml.py | 100 | 7 | 0 | 60 | 6 | 92%
manage.py | 10 | 2 | 2 | 0 | 0 | 80%

No items found using the specified filter.